@@ -1,9 +1,11 @@
 #include <stdio.h>
+#include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
 #include <linux/kd.h>
 #include <sys/ioctl.h>
 #include "nls.h"
+#include "getfd.h"
 
 /*
  * getfd.c
@@ -29,8 +31,12 @@ open_a_console(char *fnam) {
     fd = open(fnam, O_RDONLY);
     if (fd < 0 && errno == EACCES)
       fd = open(fnam, O_WRONLY);
-    if (fd < 0 || ! is_a_console(fd))
+    if (fd < 0)
       return -1;
+    if (!is_a_console(fd)) {
+      close(fd);
+      return -1;
+    }
     return fd;
 }
 
